Task

Trait Task 

pub trait Task:
    Check
    + Display
    + Send
    + Sync {
    // Required methods
    fn async_run<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<(), TaskError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn task<'async_trait>(
        self: Box<Self>,
    ) -> Pin<Box<dyn Future<Output = Result<(), TaskError>> + Send + 'async_trait>>
       where Self: 'async_trait;
    fn as_plain(&self) -> PlainActor;

    // Provided methods
    fn spawn(self) -> JoinHandle<Result<(), TaskError>>
       where Self: Sized + 'static { ... }
    fn name(&self) -> &'static str { ... }
}
Interface for running model components

Required Methods

fn async_run<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<(), TaskError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Runs the Actor infinite loop

The loop ends when the client data is None or when either the sending of receiving end of a channel is dropped

fn task<'async_trait>( self: Box<Self>, ) -> Pin<Box<dyn Future<Output = Result<(), TaskError>> + Send + 'async_trait>>
where Self: 'async_trait,

Run the actor loop

fn as_plain(&self) -> PlainActor

Provided Methods

fn spawn(self) -> JoinHandle<Result<(), TaskError>>
where Self: Sized + 'static,

Run the actor loop in a dedicated thread

fn name(&self) -> &'static str