pub struct OutputRx<U, C, const NI: usize, const NO: usize>where
U: UniqueIdentifier,
C: TryWrite<U>,{
pub actor: String,
pub output: String,
pub hash: u64,
pub rxs: Vec<Receiver<Data<U>>>,
pub client: Arc<Mutex<C>>,
}Expand description
Output signature
OutputRx contains the data of an actor output that is necessary to create the associated input for the receiving actor
Fields
actor: Stringoutput: Stringhash: u64rxs: Vec<Receiver<Data<U>>>client: Arc<Mutex<C>>Trait Implementations
Sourceimpl<U, CO, const NO: usize, const NI: usize> Debug for OutputRx<U, CO, NI, NO>where
U: 'static + UniqueIdentifier,
CO: TryWrite<U>,
impl<U, CO, const NO: usize, const NI: usize> Debug for OutputRx<U, CO, NI, NO>where
U: 'static + UniqueIdentifier,
CO: TryWrite<U>,
Sourceimpl<U, CO, const NO: usize, const NI: usize> Display for OutputRx<U, CO, NI, NO>where
U: 'static + UniqueIdentifier,
CO: TryWrite<U>,
impl<U, CO, const NO: usize, const NI: usize> Display for OutputRx<U, CO, NI, NO>where
U: 'static + UniqueIdentifier,
CO: TryWrite<U>,
Sourceimpl<U, CO, const NO: usize, const NI: usize> Error for OutputRx<U, CO, NI, NO>where
U: 'static + UniqueIdentifier,
CO: TryWrite<U>,
impl<U, CO, const NO: usize, const NI: usize> Error for OutputRx<U, CO, NI, NO>where
U: 'static + UniqueIdentifier,
CO: TryWrite<U>,
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl<U, CO, const NO: usize, const NI: usize> From<OutputRx<U, CO, NI, NO>> for ActorOutputsErrorwhere
U: 'static + UniqueIdentifier,
CO: TryWrite<U>,
impl<U, CO, const NO: usize, const NI: usize> From<OutputRx<U, CO, NI, NO>> for ActorOutputsErrorwhere
U: 'static + UniqueIdentifier,
CO: TryWrite<U>,