Struct gmt_dos_actors::model::Model

source ·
pub struct Model<State> { /* private fields */ }
Actor model

Implementations

source

impl Model<Ready>

source

pub fn run(self) -> Model<Running>

Spawns each actor task

source

impl Model<Running>

source

pub async fn wait(self) -> Result<Model<Completed>, ModelError>

Waits for the task of each actor to finish

source

impl Model<Unknown>

source

pub fn new(actors: Vec<Box<dyn Task>>) -> Self

Returns a new model

source

pub fn name<S: Into<String>>(self, name: S) -> Self

Sets the model name

source

pub fn quiet(self) -> Self

Quiet mode

source

pub fn check(self) -> Result<Model<Ready>, ModelError>

Validates actors inputs and outputs

source

pub fn skip_check(self) -> Model<Ready>

source

impl<S> Model<S>

source

pub fn inspect(self) -> Self

Prints some informations about the model and the actors within

source

pub fn n_io(&self) -> (usize, usize)

Returns the total number of inputs and the total number of outputs

Both numbers should be the same

source

pub fn n_actors(&self) -> usize

Returns the number of actors

source

pub fn get_name(&self) -> String

source

pub fn elapsed_time(&self) -> Duration