pub struct Graph { /* private fields */ }Expand description
Model network mapping
The structure is used to build a Graphviz diagram of a Model.
A new Graph is created with Model::graph().
There are 2 themes for the flowcharts: Screen with a dark background and Paper with a light background.
The theme can be set with the environment variable FLOWCHART_THEME with the values Screen and Paper.
The graph layout is either
dot,
neato,
or fdp.
The default layout is neato and it can be change by setting the environment variable FLOWCHART
to dot, neato or fdp.
Implementations