Struct gmt_dos_actors::graph::Graph

source ·
pub struct Graph { /* private fields */ }
Model network mapping

The structure is used to build a Graphviz diagram of a Model. A new Graph is created with Model::graph().

The model flow chart is written to a SVG image with <cmd> -Gstart=rand -Tsvg -O filename.dot, where <cmd> is set to the value of the environment variable FLOWCHART if given, neato otherwise

Implementations

source

impl Graph

source

pub fn new(name: String, actors: impl Into<PlainModel>) -> Self

source

pub fn to_string(&self) -> String

Returns the diagram in the Graphviz dot language

source

pub fn to_dot<P: AsRef<Path>>(&self, path: P) -> Result<(), Box<dyn Error>>

Writes the output of Graph::to_string() to a file

source

pub fn walk(&self) -> Render