Struct gmt_dos_actors::graph::Graph
source · pub struct Graph { /* private fields */ }Expand description
Model network mapping
The structure is used to build a Graphviz diagram of a Model.
A new Graph is created with Model::graph().
The model flow chart is written to a SVG image with <cmd> -Gstart=rand -Tsvg -O filename.dot,
where <cmd> is set to the value of the environment variable FLOWCHART if given, neato otherwise
Implementations